@@ -200,13 +200,43 @@
 	       t))
 	(rail-mime-save-situation-examples-original))))
 
+(defun rail-mime-save-acting-situation-examples ()
+  (save-excursion
+    (or (and rail-user-agent-convert-mime-example
+	     (set-buffer (get-buffer-create rail-temporary-buffer-name))
+	     (progn
+	       (erase-buffer)
+	       (insert mime-view-version)
+	       (goto-char (point-min))
+	       (and (looking-at rail-mime-view-version-format)
+		    (eq 'semi (cdr (assoc (buffer-substring
+					   (match-beginning 1)
+					   (match-end 1))
+					  rail-product-name-alist)))
+		    (rail-replace-codename-primitive
+		     rail-mime-view-version-format
+		     rail-additional-semi-codename-alist rail-semi-codename-alist))
+	       (let ((mime-view-version
+		      (buffer-substring (point-min) (point-max))))
+		 (rail-mime-save-acting-situation-examples-original))
+	       t))
+	(rail-mime-save-acting-situation-examples-original))))
+
 (and (fboundp 'eval-after-load)
      (eval-after-load "mime-view"
-       '(progn
-	  (if (not (fboundp 'rail-mime-save-situation-examples-original))
-	      (fset 'rail-mime-save-situation-examples-original
-		    (symbol-function 'mime-save-situation-examples)))
-	  (fset 'mime-save-situation-examples 'rail-mime-save-situation-examples))))
+       '(if (fboundp 'mime-save-situation-examples)
+	    (progn
+	      (if (not (fboundp 'rail-mime-save-situation-examples-original))
+		  (fset 'rail-mime-save-situation-examples-original
+			(symbol-function 'mime-save-situation-examples)))
+	      (fset 'mime-save-situation-examples 'rail-mime-save-situation-examples))))
+     (eval-after-load "mime-play"
+       '(if (fboundp 'mime-save-acting-situation-examples)
+	    (progn
+	      (if (not (fboundp 'rail-mime-save-acting-situation-examples-original))
+		  (fset 'rail-mime-save-acting-situation-examples-original
+			(symbol-function 'mime-save-acting-situation-examples)))
+	      (fset 'mime-save-acting-situation-examples 'rail-mime-save-acting-situation-examples)))))
 
 (provide 'rail-user-agent)
 
